/*
 * Copyright (c) 2011 ScientiaMobile, Inc., VA, USA
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.handlers;

import java.util.Collections;
import java.util.LinkedHashMap;
import java.util.Map;

import org.apache.commons.collections.map.UnmodifiableMap;

/**
 * A factory for user-agent {@link Handler}.
 * 
 * <p>
 * This class build a {@link Map} of user-agent {@link Handler} by a key.
 * </p>
 * 
 * @author WURFL-PRO SRL, Rome, Italy
 * @version $Id: HandlersFactory.java 1045 2009-03-09 15:52:53Z filippo.deluca $
 */
public class HandlersFactory {

	private static Map handlers = new LinkedHashMap();

	static {
		handlers.put(HandlerConstants.VODAFONE, new VodafoneHandler());
		handlers.put(HandlerConstants.NOKIA, new NokiaHandler());

		handlers.put(HandlerConstants.SONY_ERICSSON, new SonyEricssonHandler());

		handlers.put(HandlerConstants.MOTOROLA, new MotorolaHandler());
		handlers.put(HandlerConstants.BLACKBERRY, new BlackBerryHandler());

		handlers.put(HandlerConstants.SIEMENS, new SiemensHandler());
		handlers.put(HandlerConstants.SAGEM, new SagemHandler());

		handlers.put(HandlerConstants.SAMSUNG, new SamsungHandler());
		handlers.put(HandlerConstants.PANASONIC, new PanasonicHandler());

		handlers.put(HandlerConstants.NEC, new NecHandler());
		handlers.put(HandlerConstants.QTEK, new QtekHandler());

		handlers.put(HandlerConstants.MITSUBISHI, new MitsubishiHandler());
		handlers.put(HandlerConstants.PHILIPS, new PhilipsHandler());

		handlers.put(HandlerConstants.LG, new LGHandler());
		handlers.put(HandlerConstants.APPLE, new AppleHandler());

		handlers.put(HandlerConstants.KYOCERA, new KyoceraHandler());
		handlers.put(HandlerConstants.ALCATEL, new AlcatelHandler());

		handlers.put(HandlerConstants.SHARP, new SharpHandler());
		handlers.put(HandlerConstants.SANYO, new SanyoHandler());

		handlers.put(HandlerConstants.BENQ, new BenQHandler());
		handlers.put(HandlerConstants.PANTECH, new PantechHandler());

		handlers.put(HandlerConstants.TOSHIBA, new ToshibaHandler());
		handlers.put(HandlerConstants.GRUNDIG, new GrundigHandler());

		handlers.put(HandlerConstants.HTC, new HTCHandler());
		handlers.put(HandlerConstants.SPV, new SPVHandler());

		handlers.put(HandlerConstants.WINDOWS_CE, new WindowsCEHandler());
		handlers.put(HandlerConstants.PORTALMMM, new PortalmmmHandler());

		handlers.put(HandlerConstants.DOCOMO, new DoCoMoHandler());
		handlers.put(HandlerConstants.KDDDI, new KDDIHandler());
		
		handlers.put(HandlerConstants.AOL, new AOLHandler());
		handlers.put(HandlerConstants.OPERA, new OperaHandler());
		handlers.put(HandlerConstants.FIREFOX, new FirefoxHandler());
		handlers.put(HandlerConstants.SAFARI, new SafariHandler());
		handlers.put(HandlerConstants.MSIE, new MSIEHandler());
		
		handlers.put(HandlerConstants.CATCH_ALL, new CatchAllHandler());
	}

	/**
	 * Return the {@link Map} containig the {@link Handler}s. It is a
	 * {@link UnmodifiableMap}.
	 * 
	 * @return A {@link UnmodifiableMap} containig the {@link Handler} by
	 *         handlers key.
	 */
	public Map create() {
		return Collections.unmodifiableMap(handlers);
	}
}