/*
 * Copyright (c) 2011 ScientiaMobile, Inc., VA, USA
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.handlers.classifiers;

import java.util.HashSet;
import java.util.Set;
import java.util.SortedMap;
import java.util.SortedSet;

import org.apache.commons.collections.set.UnmodifiableSet;
import org.apache.commons.collections.set.UnmodifiableSortedSet;
import org.apache.commons.lang.builder.ToStringBuilder;

import edu.emory.mathcs.backport.java.util.concurrent.ConcurrentSkipListMap;

/**
 * Filtered device data.
 * 
 * <p>
 * This class is responsible for collect devices classified according to their
 * user-agent.
 * </p>
 * 
 * @author WURFL-PRO SRL, Rome, Italy
 * @version $Id: FilteredDevices.java 1045 2009-03-09 15:52:53Z filippo.deluca $
 */
public class FilteredDevices {

	/** The map of user-agent and device identifier. */
	private SortedMap/*String,String*/ data = new ConcurrentSkipListMap();

	/** Default constructor */
	public FilteredDevices() {
		// Empty
	}

	/**
	 * Return the collected user-agent <b>naturally ordered</b>.
	 * 
	 * @return A {@link SortedSet} containing collected user-agent.
	 */
	public SortedSet getUserAgents() {
		return UnmodifiableSortedSet.decorate((SortedSet) data.keySet());
	}

	/**
	 * Return the collected user-agent <b>naturally ordered</b>.
	 * 
	 * @return A {@link SortedSet} containing collected user-agent.
	 */
	public Set getDevices() {
		return UnmodifiableSet.decorate(new HashSet(data.values()));
	}

	/**
	 * Return a device by collected user-agent.
	 * 
	 * @param userAgent
	 *            The user-agent corresponding to the device tried.
	 * @return The device identifier collected corresponding given user-agent,
	 *         if the given user-agent is not collected it returns null.
	 */
	public String getDevice(String userAgent) {
		return (String) data.get(userAgent);
	}

	/**
	 * Store device identifier with corresponding user-agent.
	 * 
	 * @param userAgent
	 *            The user-agent corrsponding to storing device identifier.
	 * @param deviceId
	 *            The device identifier to store.
	 */
	public void putDevice(String userAgent, String deviceId) {
		data.put(userAgent, deviceId);
	}
	
	// Common methods *****************************************************

	public String toString() {
		return new ToStringBuilder(this).append(getDevices()).toString();
	}

}
