/*
 * Copyright (c) 2011 ScientiaMobile, Inc., VA, USA
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.handlers.matchers;

import java.util.SortedSet;

import net.sourceforge.wurfl.core.handlers.Handler;
import net.sourceforge.wurfl.core.handlers.classifiers.FilteredDevices;
import net.sourceforge.wurfl.core.request.WURFLRequest;

import org.apache.commons.lang.StringUtils;

/**
 * @author WURFL-PRO SRL, Rome, Italy
 * @version $Id: AppleMatcher.java 1045 2009-03-09 15:52:53Z filippo.deluca $
 */
public class AppleMatcher extends AbstractMatcher {

	private static final int APPLE_LD_TOLLERANCE = 5;

	public AppleMatcher(Handler handler) {
		super(handler);
	}

	/**
	 * Apply LD(5).
	 */
	protected String lookForMatchingUserAgent(SortedSet userAgentsSet,
			String userAgent) {
		if (logger.isDebugEnabled()) {
			logger.debug("Applying LD(" + APPLE_LD_TOLLERANCE + ") UA: "
					+ userAgent);
		}

		return net.sourceforge.wurfl.core.utils.StringUtils.ldMatch(userAgentsSet, userAgent,
				APPLE_LD_TOLLERANCE);

	}

	/**
	 * if the UA contains "iPhone" return "apple_iphone_ver1" if the UA contains
	 * "iPod" return "apple_ipod_touch_ver1"
	 */
	public String applyRecoveryMatch(WURFLRequest request, FilteredDevices filteredDevices) {
		if (StringUtils.contains(request.getUserAgent(), "iPhone")) {
			return "apple_iphone_ver1";
		}
		return "apple_ipod_touch_ver1";

	}
}
