/*
 * Copyright (c) 2011 ScientiaMobile, Inc., VA, USA
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.handlers.matchers;

import net.sourceforge.wurfl.core.Constants;
import net.sourceforge.wurfl.core.handlers.Handler;
import net.sourceforge.wurfl.core.handlers.classifiers.FilteredDevices;
import net.sourceforge.wurfl.core.request.WURFLRequest;

/**
 * @author WURFL-PRO SRL, Rome, Italy
 * @version $Id: BlackBerryMatcher.java 1045 2009-03-09 15:52:53Z filippo.deluca $
 */
public class BlackBerryMatcher extends AbstractMatcher {

	public BlackBerryMatcher(Handler handler) {
		super(handler);
	}

	/**
	 * Parse version number ("2","3.2","3.3","3.5","3.6","3.7","4.") and return
	 * "blackberry_generic_ver2","blackberry_generic_ver3_sub2",
	 * "blackberry_generic_ver3_sub30", "blackberry_generic_ver3_sub50",
	 * "blackberry_generic_ver3_sub60","blackberry_generic_ver3_sub70" or
	 * "blackberry_generic_ver4" respectively
	 */
	public String applyRecoveryMatch(WURFLRequest request, FilteredDevices filteredDevices) {
		String userAgent = request.getUserAgent();
		if (userAgent.startsWith("BlackBerry")) {

			int position = userAgent.indexOf('/');

			if (position != -1 && position + 4 <= userAgent.length()) {
				String version = userAgent.substring(position + 1, position + 4);

				if (version.startsWith("2.")) {
					return "blackberry_generic_ver2";
				}
				if (version.startsWith("3.2")) {
					return "blackberry_generic_ver3_sub2";
				}
				if (version.startsWith("3.3")) {
					return "blackberry_generic_ver3_sub30";
				}
				if (version.startsWith("3.5")) {
					return "blackberry_generic_ver3_sub50";
				}
				if (version.startsWith("3.6")) {
					return "blackberry_generic_ver3_sub60";
				}
				if (version.startsWith("3.7")) {
					return "blackberry_generic_ver3_sub70";
				}
				if (version.startsWith("4.")) {
					return "blackberry_generic_ver4";
				}

				if (logger.isWarnEnabled()) {
					logger.warn("No version matched, User-Agent: " + userAgent + " version: " + version);
				}
			}
		}
		return Constants.GENERIC;

	}

}
