/*
 * Copyright (c) 2011 ScientiaMobile, Inc., VA, USA
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.handlers.matchers;

import java.util.SortedSet;

import net.sourceforge.wurfl.core.handlers.Handler;
import net.sourceforge.wurfl.core.handlers.matchers.strategy.FirefoxTokensProvider;
import net.sourceforge.wurfl.core.handlers.matchers.strategy.TokensMatcher;

/**
 * Handles Firefox web browser using TK(2).
 */
public class FirefoxMatcher extends AbstractMatcher {
	
	public static final int FIREFOX_TK_TOLLERANCE = 2;

	private static final FirefoxTokensProvider firefoxTokens = new FirefoxTokensProvider();
	

	public FirefoxMatcher(Handler handler) {
		super(handler);
	}

	/**
	 * Apply TK(2)
	 */
	protected String lookForMatchingUserAgent(SortedSet userAgentsSet, String userAgent) {
		String match = null;
		
		if (firefoxTokens.canApply(userAgent)) {

			if (logger.isDebugEnabled()) {
				logger.debug("Applying TK(" + FIREFOX_TK_TOLLERANCE + ") UA:" + userAgent);
			}
			
			match = new TokensMatcher(firefoxTokens).match(userAgentsSet, userAgent, FIREFOX_TK_TOLLERANCE);
		}

		return match;
	}

}
