/*
 * Copyright (c) 2011 ScientiaMobile, Inc., VA, USA
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.handlers.matchers;

import java.util.SortedSet;

import net.sourceforge.wurfl.core.handlers.Handler;
import net.sourceforge.wurfl.core.utils.StringUtils;

/**
 * @author WURFL-PRO SRL, Rome, Italy
 * @version $Id: NecMatcher.java 1045 2009-03-09 15:52:53Z filippo.deluca $
 */
public class NecMatcher extends AbstractMatcher {
	
	private static final int NEC_LD_TOLLERANCE = 2;

	public NecMatcher(Handler handler) {
		super(handler);
	}

	/**
	 * If UA starts with "NEC", apply default, else apply LD(2).
	 */
	protected String lookForMatchingUserAgent(SortedSet userAgentsSet, String userAgent) {

		if (userAgent.startsWith("NEC")) {
			return super.lookForMatchingUserAgent(userAgentsSet, userAgent);
		}

		if (logger.isDebugEnabled()) {
			logger.debug("Applying LD(" + NEC_LD_TOLLERANCE + " UA: " + userAgent);
		}
		
		return StringUtils.ldMatch(userAgentsSet, userAgent, NEC_LD_TOLLERANCE);

	}

}
