/*
 * Copyright (c) 2011 ScientiaMobile, Inc., VA, USA
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.handlers.matchers;

import java.util.SortedSet;

import net.sourceforge.wurfl.core.Constants;
import net.sourceforge.wurfl.core.handlers.Handler;
import net.sourceforge.wurfl.core.handlers.classifiers.FilteredDevices;
import net.sourceforge.wurfl.core.handlers.matchers.strategy.NokiaDDDProvider;
import net.sourceforge.wurfl.core.handlers.matchers.strategy.TokensMatcher;
import net.sourceforge.wurfl.core.request.WURFLRequest;

import org.apache.commons.lang.StringUtils;

/**
 * @author WURFL-PRO SRL, Rome, Italy
 * @version $Id: NokiaMatcher.java 1045 2009-03-09 15:52:53Z filippo.deluca $
 */
public class NokiaMatcher extends AbstractMatcher {
	
	private static final int NOKIA_LD_TOLLERANCE = 4;

	private static final NokiaDDDProvider nokiaDDDTokens = new NokiaDDDProvider();

	public NokiaMatcher(Handler handler) {
		super(handler);
	}

	/**
	 * If UA starts with "Nokia" apply RIS(FS), else if UA contains version
	 * number x.x.x apply TK(9) else apply LD(4).
	 */
	protected String lookForMatchingUserAgent(SortedSet userAgentsSet,
			String userAgent) {

		String match = null;
		if (userAgent.startsWith("Nokia")) {
			int tollerance = net.sourceforge.wurfl.core.utils.StringUtils.firstSlash(userAgent);
			if (logger.isDebugEnabled()) {
				logger.debug("Applying RIS(FS) UA: " + userAgent);
			}

			match = net.sourceforge.wurfl.core.utils.StringUtils.risMatch(userAgentsSet, userAgent, tollerance);

		} else if (nokiaDDDTokens.canApply(userAgent)) {

			if (logger.isDebugEnabled()) {
				logger.debug("Applying TK(" + 9 + ") UA:" + userAgent);
			}

			match = new TokensMatcher(nokiaDDDTokens).match(userAgentsSet,
					userAgent, 9);
		}

		else {

			if (logger.isDebugEnabled()) {
				logger.debug("Applying LD with threshold: "
						+ NOKIA_LD_TOLLERANCE);
			}

			match = net.sourceforge.wurfl.core.utils.StringUtils.ldMatch(userAgentsSet, userAgent,
					NOKIA_LD_TOLLERANCE);
		}

		return match;
	}

	/**
	 * Search for "Series60" and "Series80". Return "nokia_generic_series60" and
	 * "nokia_generic_series80" respectively in case of success
	 * 
	 */
	public String applyRecoveryMatch(WURFLRequest request,
			FilteredDevices filteredDevices) {

		String userAgent = request.getUserAgent();

		if (logger.isDebugEnabled()) {
			logger.debug("Applying Nokia Recovery Match on User-Agent: "
					+ userAgent);
		}

		if (StringUtils.contains(userAgent, "Series60")) {
			return "nokia_generic_series60";
		}
		if (StringUtils.contains(userAgent, "Series80")) {
			return "nokia_generic_series80";
		}
		return Constants.GENERIC;

	}

}
