/*
 * Copyright (c) 2011 ScientiaMobile, Inc., VA, USA
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.handlers.matchers;

import java.util.SortedSet;

import net.sourceforge.wurfl.core.handlers.Handler;
import net.sourceforge.wurfl.core.handlers.matchers.strategy.LDMatcher;
import net.sourceforge.wurfl.core.handlers.matchers.strategy.RegexTokensProvider;
import net.sourceforge.wurfl.core.handlers.matchers.strategy.SPVOpVerProvider;
import net.sourceforge.wurfl.core.handlers.matchers.strategy.StringMatcher;
import net.sourceforge.wurfl.core.handlers.matchers.strategy.TokensMatcher;

/**
 * This UserAgentHandler handles the SPV devices.
 * 
 * @author WURFL-PRO SRL, Rome, Italy
 * @version $Id: SPVMatcher.java 1045 2009-03-09 15:52:53Z filippo.deluca $
 */
public class SPVMatcher extends AbstractMatcher {

	public SPVMatcher(Handler handler) {
		super(handler);
	}

	private static final RegexTokensProvider opVerTokensInfo = new SPVOpVerProvider();

	/**
	 * <p>
	 * If "OpVer x.x.x.x is present, then apply TK(7).
	 * </p>
	 * <p>
	 * Otherwise apply LD(5).
	 * </p>
	 */
	protected String lookForMatchingUserAgent(SortedSet userAgentsSet,
			String userAgent) {

		// Default values
		StringMatcher matcher = LDMatcher.INSTANCE;
		int tollerance = 5;
		
		// can apply TokensMatcher
		if (opVerTokensInfo.canApply(userAgent)) {
			
			matcher = new TokensMatcher(opVerTokensInfo);
			tollerance = 7;

			if (logger.isDebugEnabled()) {
				logger.debug("Applying TK(" + tollerance + ") UA: "	+ userAgent);
			}

		} 
		// OpVer x.x.x.x is not present
		else {
			
			matcher = LDMatcher.INSTANCE;
			tollerance = 5;
			
			if (logger.isDebugEnabled()) {
				logger.debug("Applying LD(" + tollerance + ") UA: "	+ userAgent);
			}

		}

		return matcher.match(userAgentsSet, userAgent, tollerance);
	}

}
