/*
 * Copyright (c) 2011 ScientiaMobile, Inc., VA, USA
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.handlers.matchers;

import java.util.SortedSet;

import net.sourceforge.wurfl.core.handlers.Handler;
import net.sourceforge.wurfl.core.handlers.matchers.strategy.NokiaDDDProvider;
import net.sourceforge.wurfl.core.handlers.matchers.strategy.TokensMatcher;
import net.sourceforge.wurfl.core.utils.StringUtils;

/**
 * @author WURFL-PRO SRL, Rome, Italy
 * @version $Id: VodafoneMatcher.java 1045 2009-03-09 15:52:53Z filippo.deluca $
 */
public class VodafoneMatcher extends AbstractMatcher {

	private static final int VODAFONE_TOLLERANCE = 5;

	public VodafoneMatcher(Handler handler) {
		super(handler);
	}

	/**
	 * 
	 * If UA contains "Nokia" applies TK(9), else applies LD(5).
	 */
	protected String lookForMatchingUserAgent(SortedSet userAgentsSet, String userAgent) {

		if (userAgent.indexOf("Nokia") != -1) {
			if (logger.isDebugEnabled()) {
				logger.debug("Applying TK(" + 9 + ") UA:" + userAgent);
			}

			TokensMatcher gm = new TokensMatcher(new NokiaDDDProvider());
			return gm.match(userAgentsSet, userAgent, 9);
		}
		else {

			if (logger.isDebugEnabled()) {
				logger.debug("Applying LD(" + VODAFONE_TOLLERANCE + ") UA: " + userAgent);
			}

			return StringUtils.ldMatch(userAgentsSet, userAgent, VODAFONE_TOLLERANCE);
		}

	}
}
