/*
 * Copyright (c) 2011 ScientiaMobile, Inc., VA, USA
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.handlers.matchers.strategy;

import java.util.ArrayList;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import org.apache.commons.lang.StringUtils;

/**
 * Provide tokens for Microsoft Internet Explorer
 * 
 * @author WURFL-PRO SRL, Rome, Italy
 * @version $Id: MSIETokensProvider.java 1045 2009-03-09 15:52:53Z filippo.deluca $
 */
public class MSIETokensProvider implements TokensProvider {

	private static final Pattern MSIE_VERSION_PATTERN = Pattern
			.compile("(?:MSIE ([\\.\\w]+))");
	private static final Pattern NET_VERSION_PATTERN = Pattern
			.compile("(?:NET CLR ([0-9]{1,}[\\.\\w]{0,}))");

	private static final Pattern PLATFORM_PATTERN = Pattern
			.compile("(?:Windows ([\\.\\w\\s]{0,}))");

	private static final int[] tokensWeight = {2, 2, 1};
	
	
	public List createTokens(String source) {
		List tokens = new ArrayList();
		String platform = getPlatform(source);
		String version = getVersionToken(source);
		String netVersion = getNetClrVersion(source);
		
		tokens.add(version);
		tokens.add(platform);
		tokens.add(netVersion);
		
		return tokens;
	}

	public int getTokenWeight(int index) {
		if (index > tokensWeight.length) {
			throw new IllegalArgumentException("");
		}
		return tokensWeight[index];
	}
	
	private static String getVersionToken(String source) {
		return getGroup(source, MSIE_VERSION_PATTERN);
	}
	
	private static String getPlatform(String source) {
		return getGroup(source, PLATFORM_PATTERN);
	}

	
	private static String getNetClrVersion(String source) {
		return getGroup(source, NET_VERSION_PATTERN);
	}

	private static String getGroup(String source, Pattern pattern) {
		Matcher matcher = pattern.matcher(source);
		if (matcher.find()) {
			return matcher.group(1);
		}

		return StringUtils.EMPTY;
	}
}
