/*
 * Copyright (c) 2011 ScientiaMobile, Inc., VA, USA
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.handlers.matchers.strategy;

import java.util.ArrayList;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * Implements the {@link TokensProvider} by a regex used to parse the tokens.
 * 
 * @author WURFL-PRO SRL, Rome, Italy
 * @version $Id: RegexTokensProvider.java 1045 2009-03-09 15:52:53Z filippo.deluca $
 */
public class RegexTokensProvider implements TokensProvider {

	/** Regex Pattern */
	private final Pattern pattern;

	/** Array of weights */
	private int[] weights;

	/**
	 * Build {@link TokensProvider} by regex pattern and weights arrays.
	 * 
	 * @param regex
	 *            The regex used to parse the user-agent.
	 * @param weights
	 *            The weights arrays.
	 */
	public RegexTokensProvider(String regex, int[] weights) {
		this.pattern = Pattern.compile(regex);
		this.weights = new int[weights.length];
			
		System.arraycopy(weights, 0, this.weights, 0, weights.length);
	}

	public List createTokens(String source) {

		List groups = new ArrayList();

		Matcher matcher = pattern.matcher(source);

		if (matcher.matches()) {
			int groupsCount = matcher.groupCount();

			for (int i = 1; i <= groupsCount; i++) {
				groups.add(matcher.group(i));
			}
		}

		return groups;
	}

	public int getTokenWeight(int index) {

		return weights[index];
	}

	public boolean canApply(String source) {
		Matcher matcher = pattern.matcher(source);

		return matcher.matches();
	}

}
