/*
 * Copyright (c) 2011 ScientiaMobile, Inc., VA, USA
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.handlers.matchers.strategy;

import java.util.Arrays;
import java.util.List;

/**
 * Implements {@link TokensProvider} by split the user-agent by defined string.
 * 
 * @author WURFL-PRO SRL, Rome, Italy
 * @version $Id: SplitTokensProvider.java 1045 2009-03-09 15:52:53Z filippo.deluca $
 */
public class SplitTokensProvider implements TokensProvider {

	/** The splitting string */
	private String split;

	/** The array of tokens weights */
	private int[] weights;

	/**
	 * Build {@link TokensProvider} by splitting string and weights array.
	 * 
	 * @param split
	 *            The splitting string.
	 * @param weigths
	 *            The weights array.
	 */
	public SplitTokensProvider(String split, int[] weigths) {
		this.split = split;
		this.weights = new int[weights.length];
		
		System.arraycopy(weights, 0, this.weights, 0, weights.length);
	}

	public List createTokens(String source) {

		List groups = Arrays.asList(source.split(split));

		return groups;
	}

	public int getTokenWeight(int index) {

		return weights[index];
	}

}
