/*
 * Copyright (c) 2011 ScientiaMobile, Inc., VA, USA
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.resource;

import java.io.File;
import java.io.IOException;

import org.springframework.core.io.Resource;

/**
 * Subclass of SpringWURFLResource building XMLResource as delegate.
 * 
 * @author WURFL-PRO SRL, Rome, Italy
 * @version $Id: SpringXMLResource.java 1045 2009-03-09 15:52:53Z filippo.deluca $
 */
public class SpringXMLResource extends SpringResource implements WURFLResource {

	/**
	 * Build resource by Spring Resource
	 * 
	 * @param resource
	 *            Spring Resource
	 */
	public SpringXMLResource(Resource resource) {
		super(resource);
	}

	/**
	 * Create XMLREsource as delegate.
	 * 
	 * @param resource
	 *            The Resource to create delegate from.
	 * @return WURFLResource delegate.
	 */
	protected WURFLResource createDelegate(Resource resource) {

		File file = null;

		try {
			file = resource.getFile();
		} catch (IOException e) {
			throw new WURFLResourceException(this, e);
		}

		return new XMLResource(file);
	}

}
